==> tmgmt_smartling-8.x-1.0-rc4.tar.gz: tmgmt_smartling/modules/tmgmt_smartling_context_debug/src/Form/TmgmtSmartlingContextDebugForm.php <==
<?php

namespace Drupal\tmgmt_smartling_context_debug\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form that helps to debug Smartling Context.
 */
class TmgmtSmartlingContextDebugForm extends FormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tmgmt_smartling_context_debug_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['do_direct_output'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show the context snapshot of the page in a browser.'),
      '#description' => 'If checked, the context will be shown on this page instead of being sent to Smartling.',
      '#default_value' => FALSE,
      '#required' => FALSE,
    ];

    $form['filename'] = [
      '#type' => 'textfield',
      '#title' => t('FileName'),
      '#description' => t('FileName of a Job'),
      '#default_value' => '',
      '#size' => 25,
      '#maxlength' => 25,
    ];

    $form['url'] = [
      '#type' => 'textfield',
      '#title' => t('URL'),
      '#description' => t('URL of the page to extract the context for'),
      '#default_value' => '',
      '#size' => 25,
      '#maxlength' => 125,
      '#required' => TRUE,
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('Test context'),
      '#button_type' => 'primary',
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    // \Drupal::config('tmgmt.translator.smartling')->get('settings.orgID');
    $settings = \Drupal::config('tmgmt.translator.smartling')->get('settings');

    $filename = $form_state->getValue('filename');
    $url = $form_state->getValue('url');


    /** @var \Drupal\tmgmt_smartling\Context\ContextUploader $context_uploader */
    $context_uploader = \Drupal::getContainer()->get('tmgmt_smartling.utils.context.uploader');

    if ($form_state->getValue('do_direct_output')) {
      $html = $context_uploader->getContextualizedPage($url, $settings['contextUsername'], $settings['context_silent_user_switching']);
      die($html);
    } elseif ($context_uploader->isReadyAcceptContext($filename, $settings)) {
      $response = $context_uploader->upload($url, $filename, $settings);

      $message = print_r($response, TRUE);
      \Drupal::logger('smartling_context')->info($message);
      drupal_set_message('Smartling response: ' . $message);
    }
  }
}

==> tmgmt_smartling-8.x-2.0.tar.gz: tmgmt_smartling/modules/tmgmt_smartling_context_debug/src/Form/TmgmtSmartlingContextDebugForm.php <==
<?php

namespace Drupal\tmgmt_smartling_context_debug\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form that helps to debug Smartling Context.
 */
class TmgmtSmartlingContextDebugForm extends FormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tmgmt_smartling_context_debug_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['do_direct_output'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show the context snapshot of the page in a browser.'),
      '#description' => 'If checked, the context will be shown on this page instead of being sent to Smartling.',
      '#default_value' => FALSE,
      '#required' => FALSE,
    ];

    $form['filename'] = [
      '#type' => 'textfield',
      '#title' => t('FileName'),
      '#description' => t('FileName of a Job'),
      '#default_value' => '',
      '#size' => 25,
      '#maxlength' => 25,
    ];

    $form['url'] = [
      '#type' => 'textfield',
      '#title' => t('URL'),
      '#description' => t('URL of the page to extract the context for'),
      '#default_value' => '',
      '#size' => 25,
      '#maxlength' => 125,
      '#required' => TRUE,
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('Test context'),
      '#button_type' => 'primary',
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $settings = \Drupal::config('tmgmt.translator.smartling')->get('settings');

    $filename = $form_state->getValue('filename');
    $url = $form_state->getValue('url');


    /** @var \Drupal\tmgmt_smartling\Context\ContextUploader $context_uploader */
    $context_uploader = \Drupal::getContainer()->get('tmgmt_smartling.utils.context.uploader');

    if ($form_state->getValue('do_direct_output')) {
      $html = $context_uploader->getContextualizedPage($url, $settings, TRUE);
      die($html);
    } elseif ($context_uploader->isReadyAcceptContext($filename, $settings)) {
      $response = $context_uploader->upload($url, $filename, $settings);

      $message = print_r($response, TRUE);
      \Drupal::logger('smartling_context')->info($message);
      drupal_set_message('Smartling response: ' . $message);
    }
  }
}
